@@ -9,7 +9,7 @@ import sys
 import traceback
 
 from typing import NoReturn
-from PyQt5 import QtCore, QtGui, QtWidgets
+from PyQt5 import QtCore, QtGui, QtWidgets, Qt
 
 import json
 
@@ -323,7 +323,7 @@ class CBuilder(QtWidgets.QMainWindow):
         about = options_menu.addAction("About")
         about.triggered.connect(self.about)
 
-        self.toolbar_actions = self.addToolBar("Actions")
+        # self.toolbar_actions = self.addToolBar("Actions")
         self.statusBar()
 
     def packages(self):
@@ -373,8 +373,9 @@ To upgrade see the site: \n\
 
         width_m_1 = self.info_width / 6.
         width_m_2 = (3 * self.info_width) / 6.
-        width_v_1 = self.info_height * 0.75
-        width_v_2 = self.info_height * 0.25
+        width_v_1 = self.info_height * 0.01
+        width_v_2 = self.info_height * 0.74
+        width_v_3 = self.info_height * 0.25
 
         # Second
         wsplitter = QtWidgets.QSplitter(widget_main)
@@ -387,6 +388,10 @@ To upgrade see the site: \n\
         wsplitter_centr = QtWidgets.QSplitter(wsplitter)
         wsplitter_centr.setOrientation(QtCore.Qt.Vertical)
 
+        # toolbar for wstackedwidget
+        self.toolbar_actions =Qt.QToolBar()
+        wsplitter_centr.addWidget(self.toolbar_actions)
+        
         # 1.
         self.wstackedwidget = WBaseObj(wsplitter_centr)
         wsplitter_centr.addWidget(self.wstackedwidget)
@@ -409,7 +414,7 @@ To upgrade see the site: \n\
         self.wconsole = WConsole(wsplitter_centr)
         wsplitter_centr.addWidget(self.wconsole)
 
-        wsplitter_centr.setSizes([width_v_1, width_v_2])
+        wsplitter_centr.setSizes([width_v_1, width_v_2, width_v_3])
         wsplitter.addWidget(wsplitter_centr)
 
         # Panel from right site  
